Pulse class

The Pulse SDK entry point.

Constructors

Pulse(String clientUid, String clientSecret, {String pulseHost = PulseUtils.DEFAULT_HOST, bool testing = false, PulseTheme? theme})

Properties

clientSecret String
getter/setter pair
clientUid String
getter/setter pair
config ↔ Config
getter/setter pair
defaultReports List<AbstractReport>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
log → LogLite
final
Global key for accessing the navigator and its context without needing to cache BuildContext. Pass this to your MaterialApp's navigatorKey parameter:
final
pulseHost String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme PulseTheme
getter/setter pair

Methods

addReport(AbstractReport report) → void
cleanReport(bool ok, String packName) → void
cleanReports() → void
destroy() → void
finishReport(String packName) Future<void>
getContext() BuildContext?
getReports() List<AbstractReport>
handleCategorySelected(List<AbstractReport> reportList, ReportType reportType, int? categoryIndex) Future<void>
handleError(dynamic error) Future<void>
handleTypeSelected(BuildContext context, List<AbstractReport> reportList, ReportType reportType) → void
init() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ready() bool
removeReport(AbstractReport report) → void
toString() String
A string representation of this object.
inherited
trigger() → void
triggerReports(List<AbstractReport> reportList) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearSessionProperties() → void
Clear all custom properties.
getSessionProperties() Map<String, dynamic>
Get all custom properties as a Map.
getSessionProperty(String key) → dynamic
Get a custom property value by key.
hasSessionProperty(String key) bool
Check if a property exists.
removeSessionProperty(String key) → void
Remove a specific property by key.
setSessionProperty(String key, dynamic value) → void
Set a custom property that will be included in reports.