setSessionProperty static method

void setSessionProperty(
  1. String key,
  2. dynamic value
)

Set a custom property that will be included in reports.

Properties are stored statically and shared across all Pulse instances. Use this to add custom metadata like user ID, session ID, environment, etc.

Example:

Pulse.setSessionProperty('userId', '12345');
Pulse.setSessionProperty('environment', 'production');
Pulse.setSessionProperty('version', '1.2.3');

Implementation

static void setSessionProperty(String key, dynamic value) {
  _properties[key] = value;
}